==> hildon-desktop_0.0.0-2.tar.gz: 0.0.0-2/src/hd-config.h <==
/*
 * This file is part of hildon-desktop
 *
 * Copyright (C) 2006 Nokia Corporation.
 *
 * Author:  Lucas Rocha <lucas.rocha@nokia.com>
 * Contact: Karoliina Salminen <karoliina.t.salminen@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef HD_CONFIG_FILES_H
#define HD_CONFIG_FILES_H

#define HD_DESKTOP_CONFIG_KEY_TYPE          "X-Type"
#define HD_DESKTOP_CONFIG_KEY_POSITION_X    "X-Position-X"
#define HD_DESKTOP_CONFIG_KEY_POSITION_Y    "X-Position-Y"
#define HD_DESKTOP_CONFIG_KEY_SIZE_WIDTH    "X-Size-Width"
#define HD_DESKTOP_CONFIG_KEY_SIZE_HEIGHT   "X-Size-Height"
#define HD_DESKTOP_CONFIG_KEY_ORIENTATION   "X-Orientation"
#define HD_DESKTOP_CONFIG_KEY_CONFIG_FILE   "X-Config-File"
#define HD_DESKTOP_CONFIG_KEY_PLUGIN_DIR    "X-Plugin-Dir"

#define HD_CONTAINER_TYPE_HOME              "home"
#define HD_CONTAINER_TYPE_PANEL_FIXED       "panel_fixed"
#define HD_CONTAINER_TYPE_PANEL_BOX         "panel_box"

#define HD_WINDOW_ORIENTATION_NORTH         "north"
#define HD_WINDOW_ORIENTATION_SOUTH         "south"
#define HD_WINDOW_ORIENTATION_WEST          "west"
#define HD_WINDOW_ORIENTATION_EAST          "east"

#define HD_PLUGIN_CONFIG_GROUP              "Desktop Entry"
#define HD_PLUGIN_CONFIG_KEY_NAME           "Name"
#define HD_PLUGIN_CONFIG_KEY_TYPE           "Type"

#endif

==> hildon-desktop_0.0.0-5.tar.gz: 0.0.0-5/src/hd-config.h <==
/*
 * This file is part of hildon-desktop
 *
 * Copyright (C) 2006 Nokia Corporation.
 *
 * Author:  Lucas Rocha <lucas.rocha@nokia.com>
 * Contact: Karoliina Salminen <karoliina.t.salminen@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef __HD_CONFIG_FILES_H__
#define __HD_CONFIG_FILES_H__

#define HD_DESKTOP_CONFIG_KEY_TYPE          "X-Type"
#define HD_DESKTOP_CONFIG_KEY_POSITION_X    "X-Position-X"
#define HD_DESKTOP_CONFIG_KEY_POSITION_Y    "X-Position-Y"
#define HD_DESKTOP_CONFIG_KEY_SIZE_WIDTH    "X-Size-Width"
#define HD_DESKTOP_CONFIG_KEY_SIZE_HEIGHT   "X-Size-Height"
#define HD_DESKTOP_CONFIG_KEY_ORIENTATION   "X-Orientation"
#define HD_DESKTOP_CONFIG_KEY_CONFIG_FILE   "X-Config-File"
#define HD_DESKTOP_CONFIG_KEY_PLUGIN_DIR    "X-Plugin-Dir"

#define HD_CONTAINER_TYPE_HOME              "home"
#define HD_CONTAINER_TYPE_PANEL_FIXED       "panel_fixed"
#define HD_CONTAINER_TYPE_PANEL_BOX         "panel_box"

#define HD_WINDOW_ORIENTATION_TOP           "top"
#define HD_WINDOW_ORIENTATION_BOTTOM        "bottom"
#define HD_WINDOW_ORIENTATION_LEFT          "left"
#define HD_WINDOW_ORIENTATION_RIGHT         "right"

#define HD_PLUGIN_CONFIG_GROUP              "Desktop Entry"
#define HD_PLUGIN_CONFIG_KEY_NAME           "Name"
#define HD_PLUGIN_CONFIG_KEY_TYPE           "Type"
#define HD_PLUGIN_CONFIG_KEY_PATH           "X-Path"

#define HD_PLUGIN_CONFIG_KEY_HOME_APPLET    "X-home-applet"
#define HD_PLUGIN_CONFIG_KEY_HOME_APPLET_RESIZABLE "X-home-applet-resizable"
#define HD_PLUGIN_CONFIG_KEY_HOME_MIN_WIDTH  "X-home-applet-minwidth"
#define HD_PLUGIN_CONFIG_KEY_HOME_MIN_HEIGHT "X-home-applet-minheight"

#define HD_PLUGIN_CONFIG_KEY_TN             "X-task-navigator-plugin"

#endif /* __HD_CONFIG_FILES_H__ */
